macro_rules! impl_service_adapter {
($adapter:ty, $input:ty, $output:ty, $process_fn:expr) => { ... };
}Expand description
Macro to quickly implement Service trait for adapted services
macro_rules! impl_service_adapter {
($adapter:ty, $input:ty, $output:ty, $process_fn:expr) => { ... };
}Macro to quickly implement Service trait for adapted services